﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Networking.Proximity;
using Windows.Networking.Sockets;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Microsoft.WindowsAzure.MobileServices;
using System.Globalization;
using Windows.UI.Popups;

// The Basic Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234237

namespace EasyCheckin.WindowsStore
{
    /// <summary>
    /// A basic page that provides characteristics common to most applications.
    /// </summary>
    public sealed partial class MainPage : EasyCheckin.WindowsStore.Common.LayoutAwarePage
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        /// <summary>
        /// Populates the page with content passed during navigation.  Any saved state is also
        /// provided when recreating a page from a prior session.
        /// </summary>
        /// <param name="navigationParameter">The parameter value passed to
        /// <see cref="Frame.Navigate(Type, Object)"/> when this page was initially requested.
        /// </param>
        /// <param name="pageState">A dictionary of state preserved by this page during an earlier
        /// session.  This will be null the first time a page is visited.</param>
        protected override void LoadState(Object navigationParameter, Dictionary<String, Object> pageState)
        {
            this.RefreshEvents();
        }

        private void RefreshEvents()
        {
            // Recupera la lista degli eventi ordinati per data.
            var events = (from ev in App.MobileService.GetTable<Event>()
                          where ev.Date >= DateTime.Now
                          orderby ev.Date descending
                          select ev).ToIncrementalLoadingCollection();

            // Mostra gli eventi nella GridView.
            eventsGridView.ItemsSource = events;
        }

        private async void btnAddEvent_Click(object sender, RoutedEventArgs e)
        {
            // Crea un nuovo event utilizzando i dati inseriti.
            DateTime date;
            if (!string.IsNullOrWhiteSpace(nameTextBox.Text) &&
                DateTime.TryParseExact(dateTextBox.Text, "dd/MM/yyyy", CultureInfo.InvariantCulture, DateTimeStyles.None, out date))
            {
                var newEvent = new Event
                {
                    Name = nameTextBox.Text,
                    Date = date
                };

                // Effettua l'inserimento.
                await App.MobileService.GetTable<Event>().InsertAsync(newEvent);

                // Aggiorna la lista.
                this.RefreshEvents();

                nameTextBox.Text = string.Empty;
                dateTextBox.Text = string.Empty;
            }
            else
            {
                var messageDialog = new MessageDialog("Testo non inserito oppure formato data non valido.", "Easy Check-in");
                await messageDialog.ShowAsync();
            }
        }

        private void eventsGridView_ItemClick(object sender, ItemClickEventArgs e)
        {
            var selectedEvent = e.ClickedItem as Event;
            Frame.Navigate(typeof(EventPage), selectedEvent.Id);
        }
    }
}
